R/subtyper.R
test_fused_component_set.RdThis is the core analysis engine for a single PC index. It builds
and compares models and creates plots for significant models. It uses the
robust jtools::effect_plot for all visualizations, including interactions.
test_fused_component_set(
data,
pc_index,
outcome,
covariates,
modality_prefixes,
random_effects = NULL,
predictoroperator = "+",
plot_interaction_with = NULL,
outcome_label = NULL,
predictor_name_map = NULL,
verbose = FALSE,
interact_with_all = FALSE,
p_threshold = 0.05,
...
)A list containing summary_stats, combined_plot (which may be NULL),
effect_sizes, and coefficients.